#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import claim
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class ClaimTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Claim", js["resourceType"])
        return claim.Claim(js)
    
    def testClaim1(self):
        inst = self.instantiate_from("claim-example-vision-glasses.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim1(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim1(inst2)
    
    def implClaim1(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("654321"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("660151"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happysight.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("6612346"))
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].detail[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[0].net.value, 100.0)
        self.assertEqual(inst.item[0].detail[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].detail[0].service.coding[0].code), force_bytes("frame"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[0].unitPrice.value, 100.0)
        self.assertEqual(force_bytes(inst.item[0].detail[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].net.value, 100.0)
        self.assertEqual(inst.item[0].detail[1].quantity.value, 2)
        self.assertEqual(inst.item[0].detail[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].service.coding[0].code), force_bytes("lens"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].unitPrice.value, 50.0)
        self.assertEqual(inst.item[0].detail[2].factor, 0.07)
        self.assertEqual(force_bytes(inst.item[0].detail[2].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[2].net.value, 14.0)
        self.assertEqual(inst.item[0].detail[2].sequence, 3)
        self.assertEqual(force_bytes(inst.item[0].detail[2].service.coding[0].code), force_bytes("fst"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[2].unitPrice.value, 200.0)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 214.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("glasses"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 214.0)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Vision Claim for Glasses</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("vision"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim2(self):
        inst = self.instantiate_from("claim-example-pharmacy.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim2(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim2(inst2)
    
    def implClaim2(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("654456"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("760150"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happypharma.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("7612345"))
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 60.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("smokecess"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-pharmaservice"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 60.0)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("stat"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Pharmacy Claim</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("pharmacy"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim3(self):
        inst = self.instantiate_from("claim-example-oral-identifier.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim3(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim3(inst2)
    
    def implClaim3(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("123456"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("100154"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happyvalley.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12347"))
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 135.57)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("1200"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 135.57)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">This example assumes a national health care scheme where patients, providers and organizations have known business identifiers.</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("oral"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim4(self):
        inst = self.instantiate_from("claim-example-oral-bridge.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim4(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim4(inst2)
    
    def implClaim4(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("device-bridge"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("referral"))
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.id), force_bytes("100156"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happyvalley.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("123466"))
        self.assertEqual(force_bytes(inst.information[0].category.coding[0].code), force_bytes("prosthesis"))
        self.assertEqual(force_bytes(inst.information[0].category.coding[0].system), force_bytes("http://hl7.org/fhir/claiminformationcategory"))
        self.assertEqual(force_bytes(inst.information[0].code.coding[0].code), force_bytes("2"))
        self.assertEqual(force_bytes(inst.information[0].code.coding[0].display), force_bytes("Maryland Bridge"))
        self.assertEqual(force_bytes(inst.information[0].code.coding[0].system), force_bytes("http://hl7.org/fhir/ex-oralprostho"))
        self.assertEqual(inst.information[0].sequence, 1)
        self.assertEqual(inst.information[0].timingDate.date, FHIRDate("2001-04-07").date)
        self.assertEqual(inst.information[0].timingDate.as_json(), "2001-04-07")
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].bodySite.coding[0].code), force_bytes("01"))
        self.assertEqual(force_bytes(inst.item[0].bodySite.coding[0].system), force_bytes("http://fdi.org/fhir/oraltoothcodes"))
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[0].factor, 0.75)
        self.assertEqual(inst.item[0].informationLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].locationCodeableConcept.coding[0].code), force_bytes("11"))
        self.assertEqual(force_bytes(inst.item[0].locationCodeableConcept.coding[0].system), force_bytes("http://hl7.org/fhir/ex-serviceplace"))
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 1050.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("67221"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].display), force_bytes("Maryland Bridge"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 1400.0)
        self.assertEqual(force_bytes(inst.item[1].bodySite.coding[0].code), force_bytes("21"))
        self.assertEqual(force_bytes(inst.item[1].bodySite.coding[0].system), force_bytes("http://fdi.org/fhir/oraltoothcodes"))
        self.assertEqual(inst.item[1].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[1].locationCodeableConcept.coding[0].code), force_bytes("11"))
        self.assertEqual(force_bytes(inst.item[1].locationCodeableConcept.coding[0].system), force_bytes("http://hl7.org/fhir/ex-serviceplace"))
        self.assertEqual(force_bytes(inst.item[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[1].net.value, 105.0)
        self.assertEqual(inst.item[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[1].service.coding[0].code), force_bytes("21211"))
        self.assertEqual(force_bytes(inst.item[1].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(inst.item[1].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[1].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[1].subSite[0].coding[0].code), force_bytes("L"))
        self.assertEqual(force_bytes(inst.item[1].subSite[0].coding[0].system), force_bytes("http://fdi.org/fhir/oralsurfacecodes"))
        self.assertEqual(force_bytes(inst.item[1].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[1].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[1].unitPrice.value, 105.0)
        self.assertEqual(force_bytes(inst.item[2].bodySite.coding[0].code), force_bytes("24"))
        self.assertEqual(force_bytes(inst.item[2].bodySite.coding[0].system), force_bytes("http://fdi.org/fhir/oraltoothcodes"))
        self.assertEqual(inst.item[2].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[2].detail[0].factor, 0.75)
        self.assertEqual(force_bytes(inst.item[2].detail[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[0].net.value, 750.0)
        self.assertEqual(inst.item[2].detail[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[2].detail[0].service.coding[0].code), force_bytes("27211"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[0].unitPrice.value, 1000.0)
        self.assertEqual(force_bytes(inst.item[2].detail[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[1].net.value, 350.0)
        self.assertEqual(inst.item[2].detail[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[2].detail[1].service.coding[0].code), force_bytes("lab"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[1].unitPrice.value, 350.0)
        self.assertEqual(force_bytes(inst.item[2].locationCodeableConcept.coding[0].code), force_bytes("11"))
        self.assertEqual(force_bytes(inst.item[2].locationCodeableConcept.coding[0].system), force_bytes("http://hl7.org/fhir/ex-serviceplace"))
        self.assertEqual(force_bytes(inst.item[2].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].net.value, 1100.0)
        self.assertEqual(inst.item[2].procedureLinkId[0], 1)
        self.assertEqual(inst.item[2].sequence, 3)
        self.assertEqual(force_bytes(inst.item[2].service.coding[0].code), force_bytes("27211"))
        self.assertEqual(force_bytes(inst.item[2].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(inst.item[2].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[2].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[2].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].unitPrice.value, 1100.0)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("other"))
        self.assertEqual(force_bytes(inst.payee.type.coding[0].system), force_bytes("http://hl7.org/fhir/payeetype"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(inst.procedure[0].date.date, FHIRDate("2014-07-04").date)
        self.assertEqual(inst.procedure[0].date.as_json(), "2014-07-04")
        self.assertEqual(force_bytes(inst.procedure[0].procedureCodeableConcept.text), force_bytes("Resection of gum to increase exposed tooth."))
        self.assertEqual(inst.procedure[0].sequence, 1)
        self.assertEqual(force_bytes(inst.related[0].reference.value), force_bytes("CASE156746B"))
        self.assertEqual(force_bytes(inst.related[0].relationship.coding[0].code), force_bytes("associated"))
        self.assertEqual(force_bytes(inst.related[0].relationship.coding[0].system), force_bytes("http://hl7.org/fhir/ex-relatedclaimrelationship"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Oral Health Claim</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.total.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.total.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.total.value, 2255.0)
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("oral"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim5(self):
        inst = self.instantiate_from("claim-example-pharmacy-medication.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim5(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim5(inst2)
    
    def implClaim5(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("654456"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("760151"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happypharma.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("7612345"))
        self.assertEqual(force_bytes(inst.information[0].category.coding[0].code), force_bytes("pharmacyrefill"))
        self.assertEqual(force_bytes(inst.information[0].code.coding[0].code), force_bytes("new"))
        self.assertEqual(force_bytes(inst.information[0].code.coding[0].system), force_bytes("http://hl7.org/fhir/pharmacy-refill"))
        self.assertEqual(inst.information[0].sequence, 1)
        self.assertEqual(force_bytes(inst.information[1].category.coding[0].code), force_bytes("pharmacyinformation"))
        self.assertEqual(force_bytes(inst.information[1].code.coding[0].code), force_bytes("refillsremaining"))
        self.assertEqual(force_bytes(inst.information[1].code.coding[0].system), force_bytes("http://hl7.org/fhir/pharmacy-information"))
        self.assertEqual(inst.information[1].sequence, 2)
        self.assertEqual(inst.information[1].valueQuantity.value, 2)
        self.assertEqual(force_bytes(inst.information[2].category.coding[0].code), force_bytes("pharmacyinformation"))
        self.assertEqual(force_bytes(inst.information[2].code.coding[0].code), force_bytes("dayssupply"))
        self.assertEqual(force_bytes(inst.information[2].code.coding[0].system), force_bytes("http://hl7.org/fhir/pharmacy-information"))
        self.assertEqual(inst.information[2].sequence, 3)
        self.assertEqual(inst.information[2].valueQuantity.value, 90)
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].detail[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[0].net.value, 45.0)
        self.assertEqual(inst.item[0].detail[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].detail[0].service.coding[0].code), force_bytes("drugcost"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-pharmaservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].net.value, 9.0)
        self.assertEqual(inst.item[0].detail[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].service.coding[0].code), force_bytes("markup"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-pharmaservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[2].net.value, 36.0)
        self.assertEqual(inst.item[0].detail[2].sequence, 3)
        self.assertEqual(force_bytes(inst.item[0].detail[2].service.coding[0].code), force_bytes("dispensefee"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-pharmaservice"))
        self.assertEqual(inst.item[0].informationLinkId[0], 1)
        self.assertEqual(inst.item[0].informationLinkId[1], 2)
        self.assertEqual(inst.item[0].informationLinkId[2], 3)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 90.0)
        self.assertEqual(force_bytes(inst.item[0].quantity.code), force_bytes("TAB"))
        self.assertEqual(force_bytes(inst.item[0].quantity.system), force_bytes("http://unitsofmeasure.org"))
        self.assertEqual(force_bytes(inst.item[0].quantity.unit), force_bytes("TAB"))
        self.assertEqual(inst.item[0].quantity.value, 90)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("562721"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].display), force_bytes("Alprazolam 0.25mg (Xanax)"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/RxNorm"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("stat"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Pharmacy Claim</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.total.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.total.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.total.value, 90.0)
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("pharmacy"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim6(self):
        inst = self.instantiate_from("claim-example-oral-contained-identifier.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim6(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim6(inst2)
    
    def implClaim6(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("patient-1"))
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("123456"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("100155"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happyvalley.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12347"))
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 135.57)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("1200"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 135.57)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">This example assumes a national health care scheme where patients, providers and organizations have known business identifiers.</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("oral"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim7(self):
        inst = self.instantiate_from("claim-example-professional.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim7(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim7(inst2)
    
    def implClaim7(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("654456"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("860150"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happypdocs.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("8612345"))
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 75.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("exam"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-serviceproduct"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 75.0)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Claim</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("professional"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim8(self):
        inst = self.instantiate_from("claim-example-vision-glasses-3tier.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim8(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim8(inst2)
    
    def implClaim8(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("claimresponse-1"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("device-frame"))
        self.assertEqual(force_bytes(inst.contained[2].id), force_bytes("device-lens"))
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("654321"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("660152"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happysight.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("6612347"))
        self.assertFalse(inst.insurance[0].focal)
        self.assertEqual(force_bytes(inst.insurance[0].preAuthRef[0]), force_bytes("PR7652387237"))
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertTrue(inst.insurance[1].focal)
        self.assertEqual(force_bytes(inst.insurance[1].preAuthRef[0]), force_bytes("AB543GTD7567"))
        self.assertEqual(inst.insurance[1].sequence, 2)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].category.coding[0].code), force_bytes("F6"))
        self.assertEqual(force_bytes(inst.item[0].category.coding[0].display), force_bytes("Vision Coverage"))
        self.assertEqual(force_bytes(inst.item[0].category.coding[0].system), force_bytes("http://hl7.org/fhir/benefit-subcategory"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].category.coding[0].code), force_bytes("F6"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].category.coding[0].display), force_bytes("Vision Coverage"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].category.coding[0].system), force_bytes("http://hl7.org/fhir/benefit-subcategory"))
        self.assertEqual(inst.item[0].detail[0].factor, 1.1)
        self.assertEqual(force_bytes(inst.item[0].detail[0].modifier[0].coding[0].code), force_bytes("rooh"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].modifier[0].coding[0].system), force_bytes("http://hl7.org/fhir/modifiers"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[0].net.value, 110.0)
        self.assertEqual(force_bytes(inst.item[0].detail[0].revenue.coding[0].code), force_bytes("0010"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].revenue.coding[0].display), force_bytes("Vision Clinic"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].revenue.coding[0].system), force_bytes("http://hl7.org/fhir/ex-revenue-center"))
        self.assertEqual(inst.item[0].detail[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].detail[0].service.coding[0].code), force_bytes("frame"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[0].unitPrice.value, 100.0)
        self.assertEqual(force_bytes(inst.item[0].detail[1].category.coding[0].code), force_bytes("F6"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].category.coding[0].display), force_bytes("Vision Coverage"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].category.coding[0].system), force_bytes("http://hl7.org/fhir/benefit-subcategory"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].net.value, 110.0)
        self.assertEqual(force_bytes(inst.item[0].detail[1].programCode[0].coding[0].code), force_bytes("none"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].programCode[0].coding[0].system), force_bytes("http://hl7.org/fhir/ex-programcode"))
        self.assertEqual(inst.item[0].detail[1].quantity.value, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].revenue.coding[0].code), force_bytes("0010"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].revenue.coding[0].display), force_bytes("Vision Clinic"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].revenue.coding[0].system), force_bytes("http://hl7.org/fhir/ex-revenue-center"))
        self.assertEqual(inst.item[0].detail[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].service.coding[0].code), force_bytes("lens"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].category.coding[0].code), force_bytes("F6"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].category.coding[0].display), force_bytes("Vision Coverage"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].category.coding[0].system), force_bytes("http://hl7.org/fhir/benefit-subcategory"))
        self.assertEqual(inst.item[0].detail[1].subDetail[0].factor, 1.1)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].modifier[0].coding[0].code), force_bytes("rooh"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].modifier[0].coding[0].system), force_bytes("http://hl7.org/fhir/modifiers"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].subDetail[0].net.value, 66.0)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].programCode[0].coding[0].code), force_bytes("none"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].programCode[0].coding[0].system), force_bytes("http://hl7.org/fhir/ex-programcode"))
        self.assertEqual(inst.item[0].detail[1].subDetail[0].quantity.value, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].revenue.coding[0].code), force_bytes("0010"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].revenue.coding[0].display), force_bytes("Vision Clinic"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].revenue.coding[0].system), force_bytes("http://hl7.org/fhir/ex-revenue-center"))
        self.assertEqual(inst.item[0].detail[1].subDetail[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].service.coding[0].code), force_bytes("lens"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].subDetail[0].unitPrice.value, 30.0)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].category.coding[0].code), force_bytes("F6"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].category.coding[0].display), force_bytes("Vision Coverage"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].category.coding[0].system), force_bytes("http://hl7.org/fhir/benefit-subcategory"))
        self.assertEqual(inst.item[0].detail[1].subDetail[1].factor, 1.1)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].modifier[0].coding[0].code), force_bytes("rooh"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].modifier[0].coding[0].system), force_bytes("http://hl7.org/fhir/modifiers"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].subDetail[1].net.value, 33.0)
        self.assertEqual(inst.item[0].detail[1].subDetail[1].quantity.value, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].revenue.coding[0].code), force_bytes("0010"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].revenue.coding[0].display), force_bytes("Vision Clinic"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].revenue.coding[0].system), force_bytes("http://hl7.org/fhir/ex-revenue-center"))
        self.assertEqual(inst.item[0].detail[1].subDetail[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].service.coding[0].code), force_bytes("hardening"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[1].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].subDetail[1].unitPrice.value, 15.0)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].category.coding[0].code), force_bytes("F6"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].category.coding[0].display), force_bytes("Vision Coverage"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].category.coding[0].system), force_bytes("http://hl7.org/fhir/benefit-subcategory"))
        self.assertEqual(inst.item[0].detail[1].subDetail[2].factor, 1.1)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].modifier[0].coding[0].code), force_bytes("rooh"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].modifier[0].coding[0].system), force_bytes("http://hl7.org/fhir/modifiers"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].subDetail[2].net.value, 11.0)
        self.assertEqual(inst.item[0].detail[1].subDetail[2].quantity.value, 2)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].revenue.coding[0].code), force_bytes("0010"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].revenue.coding[0].display), force_bytes("Vision Clinic"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].revenue.coding[0].system), force_bytes("http://hl7.org/fhir/ex-revenue-center"))
        self.assertEqual(inst.item[0].detail[1].subDetail[2].sequence, 3)
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].service.coding[0].code), force_bytes("UV coating"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].subDetail[2].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].subDetail[2].unitPrice.value, 5.0)
        self.assertEqual(force_bytes(inst.item[0].detail[1].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[1].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[1].unitPrice.value, 55.0)
        self.assertEqual(force_bytes(inst.item[0].detail[2].category.coding[0].code), force_bytes("F6"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].category.coding[0].display), force_bytes("Vision Coverage"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].category.coding[0].system), force_bytes("http://hl7.org/fhir/benefit-subcategory"))
        self.assertEqual(inst.item[0].detail[2].factor, 0.07)
        self.assertEqual(force_bytes(inst.item[0].detail[2].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[2].net.value, 15.4)
        self.assertEqual(force_bytes(inst.item[0].detail[2].revenue.coding[0].code), force_bytes("0010"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].revenue.coding[0].display), force_bytes("Vision Clinic"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].revenue.coding[0].system), force_bytes("http://hl7.org/fhir/ex-revenue-center"))
        self.assertEqual(inst.item[0].detail[2].sequence, 3)
        self.assertEqual(force_bytes(inst.item[0].detail[2].service.coding[0].code), force_bytes("fst"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].detail[2].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].detail[2].unitPrice.value, 220.0)
        self.assertEqual(force_bytes(inst.item[0].modifier[0].coding[0].code), force_bytes("rooh"))
        self.assertEqual(force_bytes(inst.item[0].modifier[0].coding[0].system), force_bytes("http://hl7.org/fhir/modifiers"))
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 235.4)
        self.assertEqual(force_bytes(inst.item[0].programCode[0].coding[0].code), force_bytes("none"))
        self.assertEqual(force_bytes(inst.item[0].programCode[0].coding[0].system), force_bytes("http://hl7.org/fhir/ex-programcode"))
        self.assertEqual(force_bytes(inst.item[0].revenue.coding[0].code), force_bytes("0010"))
        self.assertEqual(force_bytes(inst.item[0].revenue.coding[0].display), force_bytes("Vision Clinic"))
        self.assertEqual(force_bytes(inst.item[0].revenue.coding[0].system), force_bytes("http://hl7.org/fhir/ex-revenue-center"))
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("glasses"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-visionservice"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 235.4)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Vision Claim for Glasses</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("vision"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim9(self):
        inst = self.instantiate_from("claim-example-institutional-rich.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim9(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim9(inst2)
    
    def implClaim9(self, inst):
        self.assertEqual(inst.accident.date.date, FHIRDate("2014-07-09").date)
        self.assertEqual(inst.accident.date.as_json(), "2014-07-09")
        self.assertEqual(force_bytes(inst.accident.locationAddress.text), force_bytes("Grouse Mountain Ski Hill"))
        self.assertEqual(force_bytes(inst.accident.type.coding[0].code), force_bytes("SPT"))
        self.assertEqual(force_bytes(inst.accident.type.coding[0].display), force_bytes("Sporting Accident"))
        self.assertEqual(force_bytes(inst.accident.type.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ActIncidentCode"))
        self.assertEqual(inst.billablePeriod.end.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.billablePeriod.end.as_json(), "2014-08-16")
        self.assertEqual(inst.billablePeriod.start.date, FHIRDate("2014-08-15").date)
        self.assertEqual(inst.billablePeriod.start.as_json(), "2014-08-15")
        self.assertEqual(force_bytes(inst.careTeam[0].qualification.coding[0].code), force_bytes("physician"))
        self.assertEqual(force_bytes(inst.careTeam[0].qualification.coding[0].system), force_bytes("http://hl7.org/fhir/provider-qualification"))
        self.assertTrue(inst.careTeam[0].responsible)
        self.assertEqual(force_bytes(inst.careTeam[0].role.coding[0].code), force_bytes("primary"))
        self.assertEqual(force_bytes(inst.careTeam[0].role.coding[0].system), force_bytes("http://hl7.org/fhir/claim-careteamrole"))
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("654456"))
        self.assertEqual(force_bytes(inst.diagnosis[0].packageCode.coding[0].code), force_bytes("400"))
        self.assertEqual(force_bytes(inst.diagnosis[0].packageCode.coding[0].display), force_bytes("Head trauma - concussion"))
        self.assertEqual(force_bytes(inst.diagnosis[0].packageCode.coding[0].system), force_bytes("http://hl7.org/fhir/ex-diagnosisrelatedgroup"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.diagnosis[0].type[0].coding[0].code), force_bytes("admitting"))
        self.assertEqual(force_bytes(inst.diagnosis[0].type[0].coding[0].system), force_bytes("http://hl7.org/fhir/ex-diagnosistype"))
        self.assertEqual(inst.employmentImpacted.end.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.employmentImpacted.end.as_json(), "2014-08-16")
        self.assertEqual(inst.employmentImpacted.start.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.employmentImpacted.start.as_json(), "2014-08-16")
        self.assertEqual(inst.hospitalization.end.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.hospitalization.end.as_json(), "2014-08-16")
        self.assertEqual(inst.hospitalization.start.date, FHIRDate("2014-08-15").date)
        self.assertEqual(inst.hospitalization.start.as_json(), "2014-08-15")
        self.assertEqual(force_bytes(inst.id), force_bytes("960151"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happyhospital.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("96123451"))
        self.assertEqual(force_bytes(inst.insurance[0].businessArrangement), force_bytes("BA987123"))
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(force_bytes(inst.insurance[0].preAuthRef[0]), force_bytes("PA2014G56473"))
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 125.0)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("exam"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://hl7.org/fhir/ex-serviceproduct"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 125.0)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Claim</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.total.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.total.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.total.value, 125.0)
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("institutional"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))
    
    def testClaim10(self):
        inst = self.instantiate_from("claim-example-oral-average.json")
        self.assertIsNotNone(inst, "Must have instantiated a Claim instance")
        self.implClaim10(inst)
        
        js = inst.as_json()
        self.assertEqual("Claim", js["resourceType"])
        inst2 = claim.Claim(js)
        self.implClaim10(inst2)
    
    def implClaim10(self, inst):
        self.assertEqual(inst.careTeam[0].sequence, 1)
        self.assertEqual(inst.created.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.created.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.diagnosis[0].diagnosisCodeableConcept.coding[0].code), force_bytes("123456"))
        self.assertEqual(inst.diagnosis[0].sequence, 1)
        self.assertEqual(force_bytes(inst.id), force_bytes("100151"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://happyvalley.com/claim"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12346"))
        self.assertEqual(force_bytes(inst.information[0].category.coding[0].code), force_bytes("missingtooth"))
        self.assertEqual(force_bytes(inst.information[0].category.coding[0].system), force_bytes("http://hl7.org/fhir/claiminformationcategory"))
        self.assertEqual(force_bytes(inst.information[0].code.coding[0].code), force_bytes("15"))
        self.assertEqual(force_bytes(inst.information[0].code.coding[0].system), force_bytes("http://hl7.org/fhir/ex-tooth"))
        self.assertEqual(force_bytes(inst.information[0].reason.coding[0].code), force_bytes("e"))
        self.assertEqual(force_bytes(inst.information[0].reason.coding[0].system), force_bytes("http://hl7.org/fhir/missingtoothreason"))
        self.assertEqual(inst.information[0].sequence, 1)
        self.assertEqual(inst.information[0].timingDate.date, FHIRDate("2012-04-07").date)
        self.assertEqual(inst.information[0].timingDate.as_json(), "2012-04-07")
        self.assertEqual(force_bytes(inst.information[1].category.coding[0].code), force_bytes("exception"))
        self.assertEqual(force_bytes(inst.information[1].category.coding[0].system), force_bytes("http://hl7.org/fhir/claiminformationcategory"))
        self.assertEqual(force_bytes(inst.information[1].code.coding[0].code), force_bytes("student"))
        self.assertEqual(force_bytes(inst.information[1].code.coding[0].system), force_bytes("http://hl7.org/fhir/claim-exception"))
        self.assertEqual(inst.information[1].sequence, 2)
        self.assertEqual(force_bytes(inst.information[1].valueString), force_bytes("Happy Valley Community College"))
        self.assertTrue(inst.insurance[0].focal)
        self.assertEqual(inst.insurance[0].sequence, 1)
        self.assertEqual(inst.item[0].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].net.value, 135.57)
        self.assertEqual(inst.item[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].code), force_bytes("1200"))
        self.assertEqual(force_bytes(inst.item[0].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(inst.item[0].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[0].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[0].unitPrice.value, 135.57)
        self.assertEqual(force_bytes(inst.item[1].bodySite.coding[0].code), force_bytes("21"))
        self.assertEqual(force_bytes(inst.item[1].bodySite.coding[0].system), force_bytes("http://fdi.org/fhir/oraltoothcodes"))
        self.assertEqual(inst.item[1].careTeamLinkId[0], 1)
        self.assertEqual(force_bytes(inst.item[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[1].net.value, 105.0)
        self.assertEqual(inst.item[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[1].service.coding[0].code), force_bytes("21211"))
        self.assertEqual(force_bytes(inst.item[1].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(inst.item[1].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[1].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[1].subSite[0].coding[0].code), force_bytes("L"))
        self.assertEqual(force_bytes(inst.item[1].subSite[0].coding[0].system), force_bytes("http://fdi.org/fhir/oralsurfacecodes"))
        self.assertEqual(force_bytes(inst.item[1].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[1].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[1].unitPrice.value, 105.0)
        self.assertEqual(force_bytes(inst.item[2].bodySite.coding[0].code), force_bytes("36"))
        self.assertEqual(force_bytes(inst.item[2].bodySite.coding[0].system), force_bytes("http://fdi.org/fhir/oraltoothcodes"))
        self.assertEqual(inst.item[2].careTeamLinkId[0], 1)
        self.assertEqual(inst.item[2].detail[0].factor, 0.75)
        self.assertEqual(force_bytes(inst.item[2].detail[0].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[0].net.value, 750.0)
        self.assertEqual(inst.item[2].detail[0].sequence, 1)
        self.assertEqual(force_bytes(inst.item[2].detail[0].service.coding[0].code), force_bytes("27211"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[0].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[0].unitPrice.value, 1000.0)
        self.assertEqual(force_bytes(inst.item[2].detail[1].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[1].net.value, 350.0)
        self.assertEqual(inst.item[2].detail[1].sequence, 2)
        self.assertEqual(force_bytes(inst.item[2].detail[1].service.coding[0].code), force_bytes("lab"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].detail[1].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].detail[1].unitPrice.value, 350.0)
        self.assertEqual(force_bytes(inst.item[2].net.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].net.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].net.value, 1100.0)
        self.assertEqual(inst.item[2].sequence, 3)
        self.assertEqual(force_bytes(inst.item[2].service.coding[0].code), force_bytes("27211"))
        self.assertEqual(force_bytes(inst.item[2].service.coding[0].system), force_bytes("http://example.org/fhir/oralservicecodes"))
        self.assertEqual(inst.item[2].servicedDate.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.item[2].servicedDate.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.item[2].unitPrice.code), force_bytes("USD"))
        self.assertEqual(force_bytes(inst.item[2].unitPrice.system), force_bytes("urn:iso:std:iso:4217"))
        self.assertEqual(inst.item[2].unitPrice.value, 1100.0)
        self.assertEqual(force_bytes(inst.payee.type.coding[0].code), force_bytes("provider"))
        self.assertEqual(force_bytes(inst.priority.coding[0].code), force_bytes("normal"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the Oral Health Claim</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("oral"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/ex-claimtype"))
        self.assertEqual(force_bytes(inst.use), force_bytes("complete"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import structuremap
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class StructureMapTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("StructureMap", js["resourceType"])
        return structuremap.StructureMap(js)
    
    def testStructureMap1(self):
        inst = self.instantiate_from("structuremap-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a StructureMap instance")
        self.implStructureMap1(inst)
        
        js = inst.as_json()
        self.assertEqual("StructureMap", js["resourceType"])
        inst2 = structuremap.StructureMap(js)
        self.implStructureMap1(inst2)
    
    def implStructureMap1(self, inst):
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://hl7.org/fhir"))
        self.assertEqual(inst.date.date, FHIRDate("2017-03-09").date)
        self.assertEqual(inst.date.as_json(), "2017-03-09")
        self.assertEqual(force_bytes(inst.description), force_bytes("Example Structure Map"))
        self.assertEqual(force_bytes(inst.group[0].documentation), force_bytes("test -> testValue"))
        self.assertEqual(force_bytes(inst.group[0].input[0].mode), force_bytes("source"))
        self.assertEqual(force_bytes(inst.group[0].input[0].name), force_bytes("test"))
        self.assertEqual(force_bytes(inst.group[0].name), force_bytes("Examples"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].name), force_bytes("rule1"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].source[0].context), force_bytes("Source"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].source[0].element), force_bytes("test"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].source[0].type), force_bytes("SourceClassA"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].source[0].variable), force_bytes("t"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].target[0].context), force_bytes("Destination"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].target[0].contextType), force_bytes("variable"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].target[0].element), force_bytes("testValue"))
        self.assertEqual(force_bytes(inst.group[0].rule[0].target[0].transform), force_bytes("copy"))
        self.assertEqual(force_bytes(inst.group[0].typeMode), force_bytes("none"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("urn:ietf:rfc:3986"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("urn:oid:37843577-95fb-4adb-84c0-8837188a7bf3"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].code), force_bytes("009"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].display), force_bytes("Oceania"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].system), force_bytes("http://unstats.un.org/unsd/methods/m49/m49.htm"))
        self.assertEqual(force_bytes(inst.name), force_bytes("ExampleMap"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("HL7 FHIR Standard"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Example Map"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/StructureMap/example"))
        self.assertEqual(force_bytes(inst.version), force_bytes("0.1"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import healthcareservice
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class HealthcareServiceTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("HealthcareService", js["resourceType"])
        return healthcareservice.HealthcareService(js)
    
    def testHealthcareService1(self):
        inst = self.instantiate_from("healthcareservice-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a HealthcareService instance")
        self.implHealthcareService1(inst)
        
        js = inst.as_json()
        self.assertEqual("HealthcareService", js["resourceType"])
        inst2 = healthcareservice.HealthcareService(js)
        self.implHealthcareService1(inst2)
    
    def implHealthcareService1(self, inst):
        self.assertTrue(inst.active)
        self.assertFalse(inst.appointmentRequired)
        self.assertEqual(force_bytes(inst.availabilityExceptions), force_bytes("Reduced capacity is available during the Christmas period"))
        self.assertTrue(inst.availableTime[0].allDay)
        self.assertEqual(force_bytes(inst.availableTime[0].daysOfWeek[0]), force_bytes("wed"))
        self.assertEqual(inst.availableTime[1].availableEndTime.date, FHIRDate("05:30:00").date)
        self.assertEqual(inst.availableTime[1].availableEndTime.as_json(), "05:30:00")
        self.assertEqual(inst.availableTime[1].availableStartTime.date, FHIRDate("08:30:00").date)
        self.assertEqual(inst.availableTime[1].availableStartTime.as_json(), "08:30:00")
        self.assertEqual(force_bytes(inst.availableTime[1].daysOfWeek[0]), force_bytes("mon"))
        self.assertEqual(force_bytes(inst.availableTime[1].daysOfWeek[1]), force_bytes("tue"))
        self.assertEqual(force_bytes(inst.availableTime[1].daysOfWeek[2]), force_bytes("thu"))
        self.assertEqual(force_bytes(inst.availableTime[1].daysOfWeek[3]), force_bytes("fri"))
        self.assertEqual(inst.availableTime[2].availableEndTime.date, FHIRDate("04:30:00").date)
        self.assertEqual(inst.availableTime[2].availableEndTime.as_json(), "04:30:00")
        self.assertEqual(inst.availableTime[2].availableStartTime.date, FHIRDate("09:30:00").date)
        self.assertEqual(inst.availableTime[2].availableStartTime.as_json(), "09:30:00")
        self.assertEqual(force_bytes(inst.availableTime[2].daysOfWeek[0]), force_bytes("sat"))
        self.assertEqual(force_bytes(inst.availableTime[2].daysOfWeek[1]), force_bytes("fri"))
        self.assertEqual(force_bytes(inst.category.coding[0].code), force_bytes("8"))
        self.assertEqual(force_bytes(inst.category.coding[0].display), force_bytes("Counselling"))
        self.assertEqual(force_bytes(inst.category.coding[0].system), force_bytes("http://hl7.org/fhir/service-category"))
        self.assertEqual(force_bytes(inst.category.text), force_bytes("Counselling"))
        self.assertEqual(force_bytes(inst.characteristic[0].coding[0].display), force_bytes("Wheelchair access"))
        self.assertEqual(force_bytes(inst.comment), force_bytes("Providing Specialist psychology services to the greater Den Burg area, many years of experience dealing with PTSD issues"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("DenBurg"))
        self.assertEqual(force_bytes(inst.eligibility.coding[0].display), force_bytes("DVA Required"))
        self.assertEqual(force_bytes(inst.eligibilityNote), force_bytes("Evidence of application for DVA status may be sufficient for commencing assessment"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org/shared-ids"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("HS-12"))
        self.assertEqual(force_bytes(inst.name), force_bytes("Consulting psychologists and/or psychology services"))
        self.assertEqual(force_bytes(inst.notAvailable[0].description), force_bytes("Christmas/Boxing Day"))
        self.assertEqual(inst.notAvailable[0].during.end.date, FHIRDate("2015-12-26").date)
        self.assertEqual(inst.notAvailable[0].during.end.as_json(), "2015-12-26")
        self.assertEqual(inst.notAvailable[0].during.start.date, FHIRDate("2015-12-25").date)
        self.assertEqual(inst.notAvailable[0].during.start.as_json(), "2015-12-25")
        self.assertEqual(force_bytes(inst.notAvailable[1].description), force_bytes("New Years Day"))
        self.assertEqual(inst.notAvailable[1].during.end.date, FHIRDate("2016-01-01").date)
        self.assertEqual(inst.notAvailable[1].during.end.as_json(), "2016-01-01")
        self.assertEqual(inst.notAvailable[1].during.start.date, FHIRDate("2016-01-01").date)
        self.assertEqual(inst.notAvailable[1].during.start.as_json(), "2016-01-01")
        self.assertEqual(force_bytes(inst.programName[0]), force_bytes("PTSD outreach"))
        self.assertEqual(force_bytes(inst.referralMethod[0].coding[0].code), force_bytes("phone"))
        self.assertEqual(force_bytes(inst.referralMethod[0].coding[0].display), force_bytes("Phone"))
        self.assertEqual(force_bytes(inst.referralMethod[1].coding[0].code), force_bytes("fax"))
        self.assertEqual(force_bytes(inst.referralMethod[1].coding[0].display), force_bytes("Fax"))
        self.assertEqual(force_bytes(inst.referralMethod[2].coding[0].code), force_bytes("elec"))
        self.assertEqual(force_bytes(inst.referralMethod[2].coding[0].display), force_bytes("Secure Messaging"))
        self.assertEqual(force_bytes(inst.referralMethod[3].coding[0].code), force_bytes("semail"))
        self.assertEqual(force_bytes(inst.referralMethod[3].coding[0].display), force_bytes("Secure Email"))
        self.assertEqual(force_bytes(inst.serviceProvisionCode[0].coding[0].code), force_bytes("cost"))
        self.assertEqual(force_bytes(inst.serviceProvisionCode[0].coding[0].display), force_bytes("Fees apply"))
        self.assertEqual(force_bytes(inst.serviceProvisionCode[0].coding[0].system), force_bytes("http://hl7.org/fhir/service-provision-conditions"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].code), force_bytes("47505003"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].display), force_bytes("Posttraumatic stress disorder"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.telecom[0].system), force_bytes("phone"))
        self.assertEqual(force_bytes(inst.telecom[0].use), force_bytes("work"))
        self.assertEqual(force_bytes(inst.telecom[0].value), force_bytes("(555) silent"))
        self.assertEqual(force_bytes(inst.telecom[1].system), force_bytes("email"))
        self.assertEqual(force_bytes(inst.telecom[1].use), force_bytes("work"))
        self.assertEqual(force_bytes(inst.telecom[1].value), force_bytes("directaddress@example.com"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type[0].coding[0].code), force_bytes("394913002"))
        self.assertEqual(force_bytes(inst.type[0].coding[0].display), force_bytes("Psychotherapy"))
        self.assertEqual(force_bytes(inst.type[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.type[1].coding[0].code), force_bytes("394587001"))
        self.assertEqual(force_bytes(inst.type[1].coding[0].display), force_bytes("Psychiatry"))
        self.assertEqual(force_bytes(inst.type[1].coding[0].system), force_bytes("http://snomed.info/sct"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import basic
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class BasicTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Basic", js["resourceType"])
        return basic.Basic(js)
    
    def testBasic1(self):
        inst = self.instantiate_from("basic-example2.json")
        self.assertIsNotNone(inst, "Must have instantiated a Basic instance")
        self.implBasic1(inst)
        
        js = inst.as_json()
        self.assertEqual("Basic", js["resourceType"])
        inst2 = basic.Basic(js)
        self.implBasic1(inst2)
    
    def implBasic1(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("UMLCLASSMODEL"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://example.org/do-not-use/fhir-codes#resourceTypes"))
        self.assertEqual(force_bytes(inst.extension[0].extension[0].url), force_bytes("name"))
        self.assertEqual(force_bytes(inst.extension[0].extension[0].valueString), force_bytes("Class1"))
        self.assertEqual(force_bytes(inst.extension[0].extension[1].extension[0].url), force_bytes("name"))
        self.assertEqual(force_bytes(inst.extension[0].extension[1].extension[0].valueString), force_bytes("attribute1"))
        self.assertEqual(force_bytes(inst.extension[0].extension[1].extension[1].url), force_bytes("minOccurs"))
        self.assertEqual(inst.extension[0].extension[1].extension[1].valueInteger, 1)
        self.assertEqual(force_bytes(inst.extension[0].extension[1].extension[2].url), force_bytes("maxOccurs"))
        self.assertEqual(force_bytes(inst.extension[0].extension[1].extension[2].valueCode), force_bytes("*"))
        self.assertEqual(force_bytes(inst.extension[0].extension[1].url), force_bytes("attribute"))
        self.assertEqual(force_bytes(inst.extension[0].extension[2].extension[0].url), force_bytes("name"))
        self.assertEqual(force_bytes(inst.extension[0].extension[2].extension[0].valueString), force_bytes("attribute2"))
        self.assertEqual(force_bytes(inst.extension[0].extension[2].extension[1].url), force_bytes("minOccurs"))
        self.assertEqual(inst.extension[0].extension[2].extension[1].valueInteger, 0)
        self.assertEqual(force_bytes(inst.extension[0].extension[2].extension[2].url), force_bytes("maxOccurs"))
        self.assertEqual(inst.extension[0].extension[2].extension[2].valueInteger, 1)
        self.assertEqual(force_bytes(inst.extension[0].extension[2].url), force_bytes("attribute"))
        self.assertEqual(force_bytes(inst.extension[0].url), force_bytes("http://example.org/do-not-use/fhir-extensions/UMLclass"))
        self.assertEqual(force_bytes(inst.id), force_bytes("classModel"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testBasic2(self):
        inst = self.instantiate_from("basic-example-narrative.json")
        self.assertIsNotNone(inst, "Must have instantiated a Basic instance")
        self.implBasic2(inst)
        
        js = inst.as_json()
        self.assertEqual("Basic", js["resourceType"])
        inst2 = basic.Basic(js)
        self.implBasic2(inst2)
    
    def implBasic2(self, inst):
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Example Narrative Tester"))
        self.assertEqual(force_bytes(inst.id), force_bytes("basic-example-narrative"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
    
    def testBasic3(self):
        inst = self.instantiate_from("basic-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Basic instance")
        self.implBasic3(inst)
        
        js = inst.as_json()
        self.assertEqual("Basic", js["resourceType"])
        inst2 = basic.Basic(js)
        self.implBasic3(inst2)
    
    def implBasic3(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("referral"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://hl7.org/fhir/basic-resource-type"))
        self.assertEqual(inst.created.date, FHIRDate("2013-05-14").date)
        self.assertEqual(inst.created.as_json(), "2013-05-14")
        self.assertEqual(force_bytes(inst.extension[0].url), force_bytes("http://example.org/do-not-use/fhir-extensions/referral#requestingPractitioner"))
        self.assertEqual(force_bytes(inst.extension[1].url), force_bytes("http://example.org/do-not-use/fhir-extensions/referral#notes"))
        self.assertEqual(force_bytes(inst.extension[1].valueString), force_bytes("The patient had fever peaks over the last couple of days. He is worried about these peaks."))
        self.assertEqual(force_bytes(inst.extension[2].url), force_bytes("http://example.org/do-not-use/fhir-extensions/referral#fulfillingEncounter"))
        self.assertEqual(force_bytes(inst.id), force_bytes("referral"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://goodhealth.org/basic/identifiers"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("19283746"))
        self.assertEqual(force_bytes(inst.modifierExtension[0].url), force_bytes("http://example.org/do-not-use/fhir-extensions/referral#referredForService"))
        self.assertEqual(force_bytes(inst.modifierExtension[0].valueCodeableConcept.coding[0].code), force_bytes("11429006"))
        self.assertEqual(force_bytes(inst.modifierExtension[0].valueCodeableConcept.coding[0].display), force_bytes("Consultation"))
        self.assertEqual(force_bytes(inst.modifierExtension[0].valueCodeableConcept.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.modifierExtension[1].url), force_bytes("http://example.org/do-not-use/fhir-extensions/referral#targetDate"))
        self.assertEqual(inst.modifierExtension[1].valuePeriod.end.date, FHIRDate("2013-04-15").date)
        self.assertEqual(inst.modifierExtension[1].valuePeriod.end.as_json(), "2013-04-15")
        self.assertEqual(inst.modifierExtension[1].valuePeriod.start.date, FHIRDate("2013-04-01").date)
        self.assertEqual(inst.modifierExtension[1].valuePeriod.start.as_json(), "2013-04-01")
        self.assertEqual(force_bytes(inst.modifierExtension[2].url), force_bytes("http://example.org/do-not-use/fhir-extensions/referral#status"))
        self.assertEqual(force_bytes(inst.modifierExtension[2].valueCode), force_bytes("complete"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/ProcessResponse) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class ProcessResponse(domainresource.DomainResource):
    """ ProcessResponse resource.
    
    This resource provides processing status, errors and notes from the
    processing of a resource.
    """
    
    resource_type = "ProcessResponse"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.communicationRequest = None
        """ Request for additional information.
        List of `FHIRReference` items referencing `CommunicationRequest` (represented as `dict` in JSON). """
        
        self.created = None
        """ Creation date.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.disposition = None
        """ Disposition Message.
        Type `str`. """
        
        self.error = None
        """ Error code.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.form = None
        """ Printed Form Identifier.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ Business Identifier.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.organization = None
        """ Authoring Organization.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        self.outcome = None
        """ Processing outcome.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.processNote = None
        """ Processing comments or additional requirements.
        List of `ProcessResponseProcessNote` items (represented as `dict` in JSON). """
        
        self.request = None
        """ Request reference.
        Type `FHIRReference` referencing `Resource` (represented as `dict` in JSON). """
        
        self.requestOrganization = None
        """ Responsible organization.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        self.requestProvider = None
        """ Responsible Practitioner.
        Type `FHIRReference` referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.status = None
        """ active | cancelled | draft | entered-in-error.
        Type `str`. """
        
        super(ProcessResponse, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ProcessResponse, self).elementProperties()
        js.extend([
            ("communicationRequest", "communicationRequest", fhirreference.FHIRReference, True, None, False),
            ("created", "created", fhirdate.FHIRDate, False, None, False),
            ("disposition", "disposition", str, False, None, False),
            ("error", "error", codeableconcept.CodeableConcept, True, None, False),
            ("form", "form", codeableconcept.CodeableConcept, False, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("organization", "organization", fhirreference.FHIRReference, False, None, False),
            ("outcome", "outcome", codeableconcept.CodeableConcept, False, None, False),
            ("processNote", "processNote", ProcessResponseProcessNote, True, None, False),
            ("request", "request", fhirreference.FHIRReference, False, None, False),
            ("requestOrganization", "requestOrganization", fhirreference.FHIRReference, False, None, False),
            ("requestProvider", "requestProvider", fhirreference.FHIRReference, False, None, False),
            ("status", "status", str, False, None, False),
        ])
        return js


from . import backboneelement

class ProcessResponseProcessNote(backboneelement.BackboneElement):
    """ Processing comments or additional requirements.
    
    Suite of processing notes or additional requirements if the processing has
    been held.
    """
    
    resource_type = "ProcessResponseProcessNote"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.text = None
        """ Comment on the processing.
        Type `str`. """
        
        self.type = None
        """ display | print | printoper.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(ProcessResponseProcessNote, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ProcessResponseProcessNote, self).elementProperties()
        js.extend([
            ("text", "text", str, False, None, False),
            ("type", "type", codeableconcept.CodeableConcept, False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/DiagnosticReport) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class DiagnosticReport(domainresource.DomainResource):
    """ A Diagnostic report - a combination of request information, atomic results,
    images, interpretation, as well as formatted reports.
    
    The findings and interpretation of diagnostic  tests performed on patients,
    groups of patients, devices, and locations, and/or specimens derived from
    these. The report includes clinical context such as requesting and provider
    information, and some mix of atomic results, images, textual and coded
    interpretations, and formatted representation of diagnostic reports.
    """
    
    resource_type = "DiagnosticReport"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.basedOn = None
        """ What was requested.
        List of `FHIRReference` items referencing `CarePlan, ImmunizationRecommendation, MedicationRequest, NutritionOrder, ProcedureRequest, ReferralRequest` (represented as `dict` in JSON). """
        
        self.category = None
        """ Service category.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.code = None
        """ Name/Code for this diagnostic report.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.codedDiagnosis = None
        """ Codes for the conclusion.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.conclusion = None
        """ Clinical Interpretation of test results.
        Type `str`. """
        
        self.context = None
        """ Health care event when test ordered.
        Type `FHIRReference` referencing `Encounter, EpisodeOfCare` (represented as `dict` in JSON). """
        
        self.effectiveDateTime = None
        """ Clinically relevant time/time-period for report.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.effectivePeriod = None
        """ Clinically relevant time/time-period for report.
        Type `Period` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ Business identifier for report.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.image = None
        """ Key images associated with this report.
        List of `DiagnosticReportImage` items (represented as `dict` in JSON). """
        
        self.imagingStudy = None
        """ Reference to full details of imaging associated with the diagnostic
        report.
        List of `FHIRReference` items referencing `ImagingStudy, ImagingManifest` (represented as `dict` in JSON). """
        
        self.issued = None
        """ DateTime this version was released.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.performer = None
        """ Participants in producing the report.
        List of `DiagnosticReportPerformer` items (represented as `dict` in JSON). """
        
        self.presentedForm = None
        """ Entire report as issued.
        List of `Attachment` items (represented as `dict` in JSON). """
        
        self.result = None
        """ Observations - simple, or complex nested groups.
        List of `FHIRReference` items referencing `Observation` (represented as `dict` in JSON). """
        
        self.specimen = None
        """ Specimens this report is based on.
        List of `FHIRReference` items referencing `Specimen` (represented as `dict` in JSON). """
        
        self.status = None
        """ registered | partial | preliminary | final +.
        Type `str`. """
        
        self.subject = None
        """ The subject of the report - usually, but not always, the patient.
        Type `FHIRReference` referencing `Patient, Group, Device, Location` (represented as `dict` in JSON). """
        
        super(DiagnosticReport, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(DiagnosticReport, self).elementProperties()
        js.extend([
            ("basedOn", "basedOn", fhirreference.FHIRReference, True, None, False),
            ("category", "category", codeableconcept.CodeableConcept, False, None, False),
            ("code", "code", codeableconcept.CodeableConcept, False, None, True),
            ("codedDiagnosis", "codedDiagnosis", codeableconcept.CodeableConcept, True, None, False),
            ("conclusion", "conclusion", str, False, None, False),
            ("context", "context", fhirreference.FHIRReference, False, None, False),
            ("effectiveDateTime", "effectiveDateTime", fhirdate.FHIRDate, False, "effective", False),
            ("effectivePeriod", "effectivePeriod", period.Period, False, "effective", False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("image", "image", DiagnosticReportImage, True, None, False),
            ("imagingStudy", "imagingStudy", fhirreference.FHIRReference, True, None, False),
            ("issued", "issued", fhirdate.FHIRDate, False, None, False),
            ("performer", "performer", DiagnosticReportPerformer, True, None, False),
            ("presentedForm", "presentedForm", attachment.Attachment, True, None, False),
            ("result", "result", fhirreference.FHIRReference, True, None, False),
            ("specimen", "specimen", fhirreference.FHIRReference, True, None, False),
            ("status", "status", str, False, None, True),
            ("subject", "subject", fhirreference.FHIRReference, False, None, False),
        ])
        return js


from . import backboneelement

class DiagnosticReportImage(backboneelement.BackboneElement):
    """ Key images associated with this report.
    
    A list of key images associated with this report. The images are generally
    created during the diagnostic process, and may be directly of the patient,
    or of treated specimens (i.e. slides of interest).
    """
    
    resource_type = "DiagnosticReportImage"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.comment = None
        """ Comment about the image (e.g. explanation).
        Type `str`. """
        
        self.link = None
        """ Reference to the image source.
        Type `FHIRReference` referencing `Media` (represented as `dict` in JSON). """
        
        super(DiagnosticReportImage, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(DiagnosticReportImage, self).elementProperties()
        js.extend([
            ("comment", "comment", str, False, None, False),
            ("link", "link", fhirreference.FHIRReference, False, None, True),
        ])
        return js


class DiagnosticReportPerformer(backboneelement.BackboneElement):
    """ Participants in producing the report.
    
    Indicates who or what participated in producing the report.
    """
    
    resource_type = "DiagnosticReportPerformer"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.actor = None
        """ Practitioner or Organization  participant.
        Type `FHIRReference` referencing `Practitioner, Organization` (represented as `dict` in JSON). """
        
        self.role = None
        """ Type of performer.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(DiagnosticReportPerformer, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(DiagnosticReportPerformer, self).elementProperties()
        js.extend([
            ("actor", "actor", fhirreference.FHIRReference, False, None, True),
            ("role", "role", codeableconcept.CodeableConcept, False, None, False),
        ])
        return js


import sys
try:
    from . import attachment
except ImportError:
    attachment = sys.modules[__package__ + '.attachment']
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import appointmentresponse
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class AppointmentResponseTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("AppointmentResponse", js["resourceType"])
        return appointmentresponse.AppointmentResponse(js)
    
    def testAppointmentResponse1(self):
        inst = self.instantiate_from("appointmentresponse-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a AppointmentResponse instance")
        self.implAppointmentResponse1(inst)
        
        js = inst.as_json()
        self.assertEqual("AppointmentResponse", js["resourceType"])
        inst2 = appointmentresponse.AppointmentResponse(js)
        self.implAppointmentResponse1(inst2)
    
    def implAppointmentResponse1(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.participantStatus), force_bytes("accepted"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Accept Brian MRI results discussion</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testAppointmentResponse2(self):
        inst = self.instantiate_from("appointmentresponse-example-req.json")
        self.assertIsNotNone(inst, "Must have instantiated a AppointmentResponse instance")
        self.implAppointmentResponse2(inst)
        
        js = inst.as_json()
        self.assertEqual("AppointmentResponse", js["resourceType"])
        inst2 = appointmentresponse.AppointmentResponse(js)
        self.implAppointmentResponse2(inst2)
    
    def implAppointmentResponse2(self, inst):
        self.assertEqual(force_bytes(inst.comment), force_bytes("can't we try for this time, can't do mornings"))
        self.assertEqual(inst.end.date, FHIRDate("2013-12-25T13:30:00Z").date)
        self.assertEqual(inst.end.as_json(), "2013-12-25T13:30:00Z")
        self.assertEqual(force_bytes(inst.id), force_bytes("exampleresp"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org/sampleappointmentresponse-identifier"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("response123"))
        self.assertEqual(force_bytes(inst.participantStatus), force_bytes("tentative"))
        self.assertEqual(force_bytes(inst.participantType[0].coding[0].code), force_bytes("ATND"))
        self.assertEqual(force_bytes(inst.participantType[0].coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(inst.start.date, FHIRDate("2013-12-25T13:15:00Z").date)
        self.assertEqual(inst.start.as_json(), "2013-12-25T13:15:00Z")
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Accept Brian MRI results discussion</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import library
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class LibraryTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Library", js["resourceType"])
        return library.Library(js)
    
    def testLibrary1(self):
        inst = self.instantiate_from("library-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Library instance")
        self.implLibrary1(inst)
        
        js = inst.as_json()
        self.assertEqual("Library", js["resourceType"])
        inst2 = library.Library(js)
        self.implLibrary1(inst2)
    
    def implLibrary1(self, inst):
        self.assertEqual(force_bytes(inst.content[0].contentType), force_bytes("text/cql"))
        self.assertEqual(force_bytes(inst.content[0].url), force_bytes("library-example-content.cql"))
        self.assertEqual(force_bytes(inst.dataRequirement[0].codeFilter[0].path), force_bytes("code"))
        self.assertEqual(force_bytes(inst.dataRequirement[0].codeFilter[0].valueSetString), force_bytes("Other Female Reproductive Conditions"))
        self.assertEqual(force_bytes(inst.dataRequirement[0].type), force_bytes("Condition"))
        self.assertEqual(inst.date.date, FHIRDate("2015-07-22").date)
        self.assertEqual(inst.date.as_json(), "2015-07-22")
        self.assertEqual(force_bytes(inst.description), force_bytes("Common Logic for adherence to Chlamydia Screening guidelines"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("ChalmydiaScreening_Common"))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].type), force_bytes("depends-on"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Chlamydia Screening Common Library"))
        self.assertEqual(force_bytes(inst.topic[0].text), force_bytes("Chlamydia Screening"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("logic-library"))
        self.assertEqual(force_bytes(inst.version), force_bytes("2.0.0"))
    
    def testLibrary2(self):
        inst = self.instantiate_from("library-composition-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Library instance")
        self.implLibrary2(inst)
        
        js = inst.as_json()
        self.assertEqual("Library", js["resourceType"])
        inst2 = library.Library(js)
        self.implLibrary2(inst2)
    
    def implLibrary2(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2017-03-10").date)
        self.assertEqual(inst.date.as_json(), "2017-03-10")
        self.assertEqual(force_bytes(inst.description), force_bytes("Artifacts required for implementation of Zika Virus Management"))
        self.assertEqual(force_bytes(inst.id), force_bytes("composition-example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("Zika Artifacts"))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.relatedArtifact[1].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.relatedArtifact[2].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.relatedArtifact[3].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.relatedArtifact[4].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.relatedArtifact[5].type), force_bytes("composed-of"))
        self.assertEqual(force_bytes(inst.relatedArtifact[6].type), force_bytes("derived-from"))
        self.assertEqual(force_bytes(inst.relatedArtifact[6].url), force_bytes("https://www.cdc.gov/mmwr/volumes/65/wr/mm6539e1.htm?s_cid=mm6539e1_w"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Zika Artifacts"))
        self.assertEqual(force_bytes(inst.topic[0].text), force_bytes("Zika Virus Management"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("asset-collection"))
        self.assertEqual(force_bytes(inst.version), force_bytes("1.0.0"))
    
    def testLibrary3(self):
        inst = self.instantiate_from("library-cms146-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Library instance")
        self.implLibrary3(inst)
        
        js = inst.as_json()
        self.assertEqual("Library", js["resourceType"])
        inst2 = library.Library(js)
        self.implLibrary3(inst2)
    
    def implLibrary3(self, inst):
        self.assertEqual(force_bytes(inst.content[0].contentType), force_bytes("text/cql"))
        self.assertEqual(force_bytes(inst.content[0].url), force_bytes("library-cms146-example-content.cql"))
        self.assertEqual(force_bytes(inst.dataRequirement[0].type), force_bytes("Patient"))
        self.assertEqual(force_bytes(inst.dataRequirement[1].codeFilter[0].path), force_bytes("category"))
        self.assertEqual(force_bytes(inst.dataRequirement[1].codeFilter[0].valueCode[0]), force_bytes("diagnosis"))
        self.assertEqual(force_bytes(inst.dataRequirement[1].codeFilter[1].path), force_bytes("clinicalStatus"))
        self.assertEqual(force_bytes(inst.dataRequirement[1].codeFilter[1].valueCode[0]), force_bytes("confirmed"))
        self.assertEqual(force_bytes(inst.dataRequirement[1].codeFilter[2].path), force_bytes("code"))
        self.assertEqual(force_bytes(inst.dataRequirement[1].codeFilter[2].valueSetString), force_bytes("2.16.840.1.113883.3.464.1003.102.12.1011"))
        self.assertEqual(force_bytes(inst.dataRequirement[1].type), force_bytes("Condition"))
        self.assertEqual(force_bytes(inst.dataRequirement[2].codeFilter[0].path), force_bytes("category"))
        self.assertEqual(force_bytes(inst.dataRequirement[2].codeFilter[0].valueCode[0]), force_bytes("diagnosis"))
        self.assertEqual(force_bytes(inst.dataRequirement[2].codeFilter[1].path), force_bytes("clinicalStatus"))
        self.assertEqual(force_bytes(inst.dataRequirement[2].codeFilter[1].valueCode[0]), force_bytes("confirmed"))
        self.assertEqual(force_bytes(inst.dataRequirement[2].codeFilter[2].path), force_bytes("code"))
        self.assertEqual(force_bytes(inst.dataRequirement[2].codeFilter[2].valueSetString), force_bytes("2.16.840.1.113883.3.464.1003.102.12.1012"))
        self.assertEqual(force_bytes(inst.dataRequirement[2].type), force_bytes("Condition"))
        self.assertEqual(force_bytes(inst.dataRequirement[3].codeFilter[0].path), force_bytes("status"))
        self.assertEqual(force_bytes(inst.dataRequirement[3].codeFilter[0].valueCode[0]), force_bytes("finished"))
        self.assertEqual(force_bytes(inst.dataRequirement[3].codeFilter[1].path), force_bytes("class"))
        self.assertEqual(force_bytes(inst.dataRequirement[3].codeFilter[1].valueCode[0]), force_bytes("ambulatory"))
        self.assertEqual(force_bytes(inst.dataRequirement[3].codeFilter[2].path), force_bytes("type"))
        self.assertEqual(force_bytes(inst.dataRequirement[3].codeFilter[2].valueSetString), force_bytes("2.16.840.1.113883.3.464.1003.101.12.1061"))
        self.assertEqual(force_bytes(inst.dataRequirement[3].type), force_bytes("Encounter"))
        self.assertEqual(force_bytes(inst.dataRequirement[4].codeFilter[0].path), force_bytes("diagnosis"))
        self.assertEqual(force_bytes(inst.dataRequirement[4].codeFilter[0].valueSetString), force_bytes("2.16.840.1.113883.3.464.1003.198.12.1012"))
        self.assertEqual(force_bytes(inst.dataRequirement[4].type), force_bytes("DiagnosticReport"))
        self.assertEqual(force_bytes(inst.dataRequirement[5].codeFilter[0].path), force_bytes("code"))
        self.assertEqual(force_bytes(inst.dataRequirement[5].codeFilter[0].valueSetString), force_bytes("2.16.840.1.113883.3.464.1003.196.12.1001"))
        self.assertEqual(force_bytes(inst.dataRequirement[5].type), force_bytes("Medication"))
        self.assertEqual(force_bytes(inst.dataRequirement[6].codeFilter[0].path), force_bytes("status"))
        self.assertEqual(force_bytes(inst.dataRequirement[6].codeFilter[0].valueCode[0]), force_bytes("active"))
        self.assertEqual(force_bytes(inst.dataRequirement[6].codeFilter[1].path), force_bytes("medication.code"))
        self.assertEqual(force_bytes(inst.dataRequirement[6].codeFilter[1].valueSetString), force_bytes("2.16.840.1.113883.3.464.1003.196.12.1001"))
        self.assertEqual(force_bytes(inst.dataRequirement[6].type), force_bytes("MedicationRequest"))
        self.assertEqual(force_bytes(inst.dataRequirement[7].codeFilter[0].path), force_bytes("status"))
        self.assertEqual(force_bytes(inst.dataRequirement[7].codeFilter[0].valueCode[0]), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.dataRequirement[7].codeFilter[1].path), force_bytes("medication.code"))
        self.assertEqual(force_bytes(inst.dataRequirement[7].codeFilter[1].valueSetString), force_bytes("2.16.840.1.113883.3.464.1003.196.12.1001"))
        self.assertEqual(force_bytes(inst.dataRequirement[7].type), force_bytes("MedicationStatement"))
        self.assertEqual(inst.date.date, FHIRDate("2015-07-22").date)
        self.assertEqual(inst.date.as_json(), "2015-07-22")
        self.assertEqual(force_bytes(inst.description), force_bytes("Logic for CMS 146: Appropriate Testing for Children with Pharyngitis"))
        self.assertEqual(force_bytes(inst.id), force_bytes("library-cms146-example"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("CMS146"))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].type), force_bytes("depends-on"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Appropriate Testing for Children with Pharyngitis"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("logic-library"))
        self.assertEqual(force_bytes(inst.version), force_bytes("2.0.0"))
    
    def testLibrary4(self):
        inst = self.instantiate_from("library-predecessor-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Library instance")
        self.implLibrary4(inst)
        
        js = inst.as_json()
        self.assertEqual("Library", js["resourceType"])
        inst2 = library.Library(js)
        self.implLibrary4(inst2)
    
    def implLibrary4(self, inst):
        self.assertEqual(force_bytes(inst.content[0].contentType), force_bytes("text/cql"))
        self.assertEqual(force_bytes(inst.content[0].title), force_bytes("FHIR Helpers"))
        self.assertEqual(force_bytes(inst.content[0].url), force_bytes("library-fhir-helpers-content.cql"))
        self.assertEqual(inst.date.date, FHIRDate("2016-11-14").date)
        self.assertEqual(inst.date.as_json(), "2016-11-14")
        self.assertEqual(force_bytes(inst.description), force_bytes("FHIR Helpers"))
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.id), force_bytes("library-fhir-helpers-predecessor"))
        self.assertEqual(force_bytes(inst.identifier[0].use), force_bytes("official"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("FHIRHelpers"))
        self.assertEqual(force_bytes(inst.relatedArtifact[0].type), force_bytes("depends-on"))
        self.assertEqual(force_bytes(inst.relatedArtifact[1].type), force_bytes("successor"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("FHIR Helpers"))
        self.assertEqual(force_bytes(inst.topic[0].text), force_bytes("FHIR Helpers"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("logic-library"))
        self.assertEqual(force_bytes(inst.version), force_bytes("1.6"))

